@@ -1,5 +1,6 @@
 import qrunner
 from qrunner import Elem
+from qrunner.core.ocr.element import OCRElem
 
 
 class HomePage(qrunner.Page):
@@ -14,14 +15,14 @@ class HomePage(qrunner.Page):
 
 class PatentPage(qrunner.Page):
     """查专利首页"""
-    report_entry = Elem(ocr='分析报告', desc='分析报告入口')
-    tech_entry = Elem(ocr='技术全景报告', desc='技术全景报告入口')
-    create_tech = Elem(ocr='创建技术全景报告', desc='创建技术报告标题')
+    report_entry = Elem(text='分析报告', desc='分析报告入口')
+    tech_entry = Elem(text='技术全景报告', desc='技术全景报告入口')
+    create_tech = Elem(text='创建技术全景报告', desc='创建技术报告标题')
 
     def go_tech_report(self):
-        self.elem(self.report_entry).click()
-        self.elem(self.tech_entry).click()
-        assert self.elem(self.create_tech).exists()
+        OCRElem(self.driver, **self.report_entry).click()
+        OCRElem(self.driver, **self.tech_entry).click()
+        assert OCRElem(self.driver, **self.create_tech).exists()
 
 
 class TestAdvancedSearch(qrunner.TestCase):
