@@ -9,7 +9,6 @@ from jsonschema.exceptions import ValidationError
 from qrunner.core.android.driver import AndroidDriver
 from qrunner.core.android.element import AdrElem
 from qrunner.core.api.request import HttpRequest, ResponseResult, formatting
-from qrunner.core.h5.driver import H5Driver
 from qrunner.core.ios.driver import IosDriver
 from qrunner.core.ios.element import IosElem
 from qrunner.core.web.driver import WebDriver
@@ -17,7 +16,7 @@ from qrunner.core.web.element import WebElem
 from qrunner.utils.config import config
 from qrunner.utils.log import logger
 from qrunner.running.config import Qrunner
-from qrunner.utils.exceptions import PlatformError, NoSuchDriverType
+from qrunner.utils.exceptions import PlatformError, NoSuchDriverType, ElementNameEmptyException
 
 
 class TestCase(HttpRequest):
@@ -25,7 +24,7 @@ class TestCase(HttpRequest):
     测试用例基类，所有测试用例需要继承该类
     """
 
-    driver: Union[AndroidDriver, IosDriver, WebDriver, H5Driver] = None
+    driver: Union[AndroidDriver, IosDriver, WebDriver] = None
 
     # ---------------------初始化-------------------------------
     def start_class(self):
@@ -94,20 +93,67 @@ class TestCase(HttpRequest):
 
     # 公共方法
     @staticmethod
-    def sleep(n: int):
+    def sleep(n: float):
         """休眠"""
         logger.debug(f"等待: {n}s")
         time.sleep(n)
 
     # UI自动化
-    def elem(self, *args, **kwargs):
+    def elem(self,
+             res_id: str = None,
+             class_name: str = None,
+             text: str = None,
+             name: str = None,
+             label: str = None,
+             value: str = None,
+             id_: str = None,
+             link_text: str = None,
+             partial_link_text: str = None,
+             tag_name: str = None,
+             css: str = None,
+             xpath: str = None,
+             index: int = None,
+             desc: str = None
+             ):
+        _kwargs = {}
+        if res_id is not None:
+            _kwargs["res_id"] = res_id
+        if class_name is not None:
+            _kwargs["class_name"] = class_name
+        if text is not None:
+            _kwargs["text"] = text
+        if name is not None:
+            _kwargs["name"] = name
+        if label is not None:
+            _kwargs["label"] = label
+        if value is not None:
+            _kwargs["value"] = value
+        if id_ is not None:
+            _kwargs["id_"] = id_
+        if link_text is not None:
+            _kwargs["link_text"] = link_text
+        if partial_link_text is not None:
+            _kwargs["partial_link_text"] = partial_link_text
+        if tag_name is not None:
+            _kwargs["tag_name"] = tag_name
+        if css is not None:
+            _kwargs["css"] = css
+        if xpath is not None:
+            _kwargs["xpath"] = xpath
+        if index is not None:
+            _kwargs["index"] = index
+        if desc is None:
+            raise ElementNameEmptyException("请设置控件名称")
+        else:
+            _kwargs["desc"] = desc
+
         """封装安卓、ios、web元素"""
         if isinstance(self.driver, AndroidDriver):
-            return AdrElem(self.driver, *args, **kwargs)
+            return AdrElem(self.driver, **_kwargs)
         elif isinstance(self.driver, IosDriver):
-            return IosElem(self.driver, *args, **kwargs)
+            return IosElem(self.driver, **_kwargs)
         elif isinstance(self.driver, WebDriver):
-            return WebElem(self.driver, *args, **kwargs)
+            return WebElem(self.driver, **_kwargs)
         else:
             raise NoSuchDriverType('不支持的驱动类型')
 
@@ -116,7 +162,7 @@ class TestCase(HttpRequest):
         for _ in range(timeout + 1):
             try:
                 page_source = self.driver.page_content
-                logger.info(f"断言: {page_source}\n包含 {expect_value}")
+                logger.info(f"断言: 页面内容包含 {expect_value}")
                 assert expect_value in page_source, f"页面内容不包含 {expect_value}"
                 break
             except AssertionError:
@@ -126,12 +172,18 @@ class TestCase(HttpRequest):
             logger.info(f"断言: {page_source}\n包含 {expect_value}")
             assert expect_value in page_source, f"页面内容不包含 {expect_value}"
 
+    def is_in_page(self, expect_value, timeout=5):
+        """页面是否包含文本"""
+        self.sleep(timeout)
+        page_source = self.driver.page_content
+        return True if expect_value in page_source else False
+
     def assert_not_in_page(self, expect_value, timeout=5):
         """断言页面不包含文本"""
         for _ in range(timeout + 1):
             try:
                 page_source = self.driver.page_content
-                logger.info(f"断言: {page_source}\n不包含 {expect_value}")
+                logger.info(f"断言: 页面内容不包含 {expect_value}")
                 assert expect_value not in page_source, f"页面内容不包含 {expect_value}"
                 break
             except AssertionError:
@@ -141,6 +193,16 @@ class TestCase(HttpRequest):
             logger.info(f"断言: {page_source}\n不包含 {expect_value}")
             assert expect_value not in page_source, f"页面内容仍然包含 {expect_value}"
 
+    def is_title(self, expect_value=None, timeout=5):
+        """断言页面标题等于"""
+        for _ in range(timeout + 1):
+            title = self.driver.title
+            if expect_value == title:
+                return True
+            self.sleep(1)
+        else:
+            return False
+
     def assert_title(self, expect_value=None, timeout=5):
         """断言页面标题等于"""
         for _ in range(timeout + 1):
@@ -156,6 +218,16 @@ class TestCase(HttpRequest):
             logger.info(f"断言: 页面标题 {title} 等于 {expect_value}")
             assert expect_value == title, f"页面标题 {title} 不等于 {expect_value}"
 
+    def is_in_title(self, expect_value=None, timeout=5):
+        """断言页面标题等于"""
+        for _ in range(timeout + 1):
+            title = self.driver.title
+            if expect_value in title:
+                return True
+            self.sleep(1)
+        else:
+            return False
+
     def assert_in_title(self, expect_value=None, timeout=5):
         """断言页面标题包含"""
         for _ in range(timeout + 1):
