@@ -10,8 +10,6 @@ from qrunner.utils.exceptions import (
     NoSuchElementException,
     DriverNotFound)
 from qrunner.utils.log import logger
-from qrunner.core.image.element import ImageElem
-from qrunner.core.ocr.element import OCRElem
 
 
 class AdrElem(object):
@@ -123,16 +121,11 @@ class AdrElem(object):
 
     def exists(self, timeout=3):
         logger.info(f"判断元素是否存在")
-        if self._image is not None:
-            return self.image_exists(timeout=timeout)
-        elif self._ocr is not None:
-            return self.ocr_exists(timeout=timeout)
-        else:
-            element = self.find_element(retry=0, timeout=timeout)
-            if element is None:
-                # self._driver.screenshot(f'元素定位失败')
-                return False
-            return True
+        element = self.find_element(retry=0, timeout=timeout)
+        if element is None:
+            # self._driver.screenshot(f'元素定位失败')
+            return False
+        return True
 
     @staticmethod
     def _adapt_center(e: typing.Union[UiObject, XPathSelector], offset=(0.5, 0.5)):
@@ -143,16 +136,11 @@ class AdrElem(object):
 
     def click(self, retry=3, timout=3):
         logger.info(f"点击元素")
-        if self._image is not None:
-            self.image_click(retry=retry, timeout=timout)
-        elif self._ocr is not None:
-            self.ocr_click(retry=retry, timeout=timout)
-        else:
-            element = self.get_element(retry=retry, timeout=timout)
-            # 这种方式经常点击不成功，感觉是页面刷新有影响
-            # element.click()
-            x, y = self._adapt_center(element)
-            self._driver.d.click(x, y)
+        element = self.get_element(retry=retry, timeout=timout)
+        # 这种方式经常点击不成功，感觉是页面刷新有影响
+        # element.click()
+        x, y = self._adapt_center(element)
+        self._driver.d.click(x, y)
 
     def click_exists(self, timeout=3):
         logger.info(f"元素存在才点击")
@@ -187,26 +175,6 @@ class AdrElem(object):
         logger.info(f"下滑")
         self.get_element().swipe("down")
 
-    def image_click(self, retry=3, timeout=3):
-        """图像识别点击"""
-        _element = ImageElem(self._driver, image=self._image, desc=self._desc)
-        _element.click(retry=retry, timeout=timeout)
-
-    def image_exists(self, retry=3, timeout=3):
-        """图像是否存在"""
-        _element = ImageElem(self._driver, image=self._image, desc=self._desc)
-        return _element.exists(retry=retry, timeout=timeout)
-
-    def ocr_click(self, retry=3, timeout=1):
-        """ocr识别点击"""
-        _element = OCRElem(self._driver, text=self._ocr, desc=self._desc)
-        _element.click(retry=retry, timeout=timeout)
-
-    def ocr_exists(self, retry=3, timeout=1):
-        """文本是否在图像中存在"""
-        _element = OCRElem(self._driver, text=self._ocr, desc=self._desc)
-        return _element.exists(retry=retry, timeout=timeout)
-
 
 if __name__ == '__main__':
     driver = AndroidDriver()
