@@ -7,10 +7,8 @@ import sys
 from urllib import parse
 
 import requests
-from deepdiff import DeepDiff
 
 from qrunner.utils.config import config
-from qrunner.utils.json_utils import formatting, get_schema
 from qrunner.utils.log import logger
 
 # 去掉requests本身的日志
@@ -18,6 +16,13 @@ urllib3_logger = logging.getLogger("urllib3")
 urllib3_logger.setLevel(logging.CRITICAL)
 
 
+def formatting(msg):
+    """formatted message"""
+    if isinstance(msg, dict):
+        return json_util.dumps(msg, indent=2, ensure_ascii=False)
+    return msg
+
+
 def request(func):
     def wrapper(*args, **kwargs):
         logger.info("-------------- Request -----------------[🚀]")
@@ -123,91 +128,20 @@ class ResponseResult:
 class HttpRequest(object):
     @request
     def get(self, url, params=None, login=True, **kwargs):
-        # if "http" not in url:
-        #     base_url = conf.get_item('common', 'base_url')
-        #     if 'http' in base_url:
-        #         url = parse.urljoin(base_url, url)
-        #     else:
-        #         logger.debug('请设置正确的base_url')
-        #         sys.exit()
         return requests.get(url, params=params, **kwargs)
 
-    def get_req_schema(self, *args, **kwargs):
-        """get请求，检查多次请求返回的schema是否稳定"""
-        exclude_paths = kwargs.pop("exclude_paths", {})
-        execute_time = kwargs.pop("execute_time", 10)
-
-        self.get(*args, **kwargs)
-        schema_start = get_schema(self.response)
-        diff_result = []
-
-        for i in range(execute_time):
-            logger.debug(f"第 {i+1} 次执行")
-            self.get(*args, **kwargs)
-            schema_ = get_schema(self.response)
-            result = DeepDiff(schema_start, schema_, exclude_paths=exclude_paths)
-            diff_result.append(result)
-
-        logger.debug(f"diff结果:")
-        for item in diff_result:
-            for item_ in item.items():
-                print(item_)
-
     @request
     def post(self, url, data=None, json=None, login=True, **kwargs):
-        # if "http" not in url:
-        #     base_url = conf.get_item('common', 'base_url')
-        #     logger.debug(base_url)
-        #     if 'http' in base_url:
-        #         url = parse.urljoin(base_url, url)
-        #     else:
-        #         logger.debug('请设置正确的base_url')
-        #         sys.exit()
         return requests.post(url, data=data, json=json, **kwargs)
 
-    def post_req_schema(self, *args, **kwargs):
-        """post请求，检查多次请求返回的schema是否稳定"""
-        exclude_paths = kwargs.pop("exclude_paths", {})
-        execute_time = kwargs.pop("execute_time", 10)
-
-        self.post(*args, **kwargs)
-        schema_start = get_schema(self.response)
-        diff_result = []
-
-        for i in range(execute_time):
-            logger.debug(f"第 {i+1} 次执行")
-            self.post(*args, **kwargs)
-            schema_ = get_schema(self.response)
-            result = DeepDiff(schema_start, schema_, exclude_paths=exclude_paths)
-            diff_result.append(result)
-
-        logger.debug(f"diff结果:")
-        for item in diff_result:
-            for item_ in item.items():
-                print(item_)
-
     @request
     def put(self, url, data=None, json=None, login=True, **kwargs):
-        # if "http" not in url:
-        #     base_url = conf.get_item('common', 'base_url')
-        #     if 'http' in base_url:
-        #         url = parse.urljoin(base_url, url)
-        #     else:
-        #         logger.debug('请设置正确的base_url')
-        #         sys.exit()
         if json is not None:
             data = json_util.dumps(json)
         return requests.put(url, data=data, **kwargs)
 
     @request
     def delete(self, url, login=True, **kwargs):
-        # if "http" not in url:
-        #     base_url = conf.get_item('common', 'base_url')
-        #     if 'http' in base_url:
-        #         url = parse.urljoin(base_url, url)
-        #     else:
-        #         logger.debug('请设置正确的base_url')
-        #         sys.exit()
         return requests.delete(url, **kwargs)
 
     @property
