@@ -6,9 +6,9 @@ import time
 import allure
 import requests
 from selenium import webdriver
+from selenium.common.exceptions import NoAlertPresentException
 
 from qrunner.core.android.driver import AndroidDriver
-from qrunner.core.web.element import WebElement
 from qrunner.utils.config import config
 from qrunner.utils.exceptions import ScreenFailException
 from qrunner.utils.log import logger
@@ -76,27 +76,11 @@ def get_driver_version(serial_no, pkg_name):
 
 
 class H5Driver(object):
-    # _instance = {}
-    #
-    # def __new__(cls, serial_no=None):
-    #     if not serial_no:
-    #         serial_no = conf.get_name('app', 'serial_no')
-    #     if serial_no not in cls._instance:
-    #         cls._instance[serial_no] = super().__new__(cls)
-    #     return cls._instance[serial_no]
 
     def __init__(self, android_driver: AndroidDriver):
-        serial_no = android_driver.serial_no
+        serial_no = android_driver.device_id
         pkg_name = android_driver.pkg_name
 
-        # # 判断应用是否已启动
-        # pid = android_driver.wait_app_running()
-        # if pid:
-        #     logger.debug('应用已启动')
-        # else:
-        #     logger.debug('应用未启动，h5Driver初始化失败')
-        #     sys.exit()
-
         logger.info(f"启动H5Driver for {serial_no}")
         options = webdriver.ChromeOptions()
         options.add_experimental_option("androidDeviceSerial", serial_no)
@@ -124,16 +108,35 @@ class H5Driver(object):
         # 设置页面加载超时时间
         self.d.set_page_load_timeout(config.get_timeout())
 
-    # @staticmethod
-    # def get_instance(cls, serial_no=None):
-    #     if serial_no not in cls._instance:
-    #         logger.info(f'{serial_no} Create h5 driver singleton')
-    #         return H5Driver(serial_no)
-    #     return H5Driver._instance[serial_no]
+    @property
+    def page_content(self):
+        page_source = self.d.page_source
+        logger.info(f"获取页面内容: \n{page_source}")
+        return page_source
 
-    @staticmethod
-    def get_elem(**kwargs):
-        return WebElement(**kwargs)
+    @property
+    def title(self):
+        logger.info("获取页面标题")
+        title = self.d.title
+        logger.info(title)
+        return title
+
+    @property
+    def url(self):
+        logger.info("获取页面url")
+        url = self.d.current_url
+        logger.info(url)
+        return url
+
+    @property
+    def alert_text(self):
+        logger.info("获取alert的文本")
+        try:
+            alert_text = self.d.switch_to.alert.text
+        except NoAlertPresentException:
+            logger.info(f'没有出现alert')
+            return None
+        return alert_text
 
     def open_url(self, url):
         logger.info(f"访问: {url}")
@@ -144,11 +147,25 @@ class H5Driver(object):
         self.d.back()
 
     def screenshot(self, file_name):
+        """截图"""
+        if "." in file_name:
+            file_name = file_name.split(r".")[0]
+        # 截图并保存到当前目录的images文件夹中
+        img_dir = os.path.join(os.getcwd(), "images")
+        if os.path.exists(img_dir) is False:
+            os.mkdir(img_dir)
+        file_path = os.path.join(img_dir, f'{file_name}.png')
+        logger.info(f'截图保存至: {file_path}')
+        self.d.save_screenshot(file_path)
+        return file_path
+
+    def screenshot_with_time(self, file_name):
         """
         截图并保存到预定路径
         @param file_name: foo.png or fool
         @return:
         """
+        logger.info(f'截图: {file_name}')
         try:
             # 把文件名处理成test.png的样式
             if "." in file_name:
@@ -170,53 +187,6 @@ class H5Driver(object):
         except Exception as e:
             raise ScreenFailException(f"{file_name} 截图失败\n{str(e)}")
 
-    # def screenshot_and_mark(self, file_name, rect):
-    #     """给图片指定范围画上红框
-    #     rect: [x, y, width, height]
-    #     x: 左上坐标x
-    #     y：左上角坐标y
-    #     width：矩形宽度
-    #     height：矩形高度
-    #     """
-    #     # 把文件名处理成test.png的样式
-    #     if '.' in file_name:
-    #         file_name = file_name.split(r'.')[0]
-    #     # 截图并保存到当前目录的images文件夹中
-    #     img_dir = os.path.join(os.getcwd(), 'images')
-    #     if os.path.exists(img_dir) is False:
-    #         os.mkdir(img_dir)
-    #     time_str = time.strftime('%Y年%m月%d日 %H时%M分%S秒')
-    #     file_path = os.path.join(img_dir, f'{time_str}-{file_name}.png')
-    #     self.d.save_screenshot(file_path)
-    #     # 画框
-    #     ImageRecognition.mark(file_path, rect)
-    #     # 上传allure报告
-    #     allure.attach.file(file_path, attachment_type=allure.attachment_type.PNG, name=f'{file_name}.png')
-    #     return file_path
-
-    # @relaunch
-    # def upload_pic(self, filename):
-    #     # allure.attach.file(self.d.get_screenshot_as_png(),
-    #     #                    attachment_type=allure.attachment_type.PNG,
-    #     #                    name=f'{filename}')
-    #     self.d.save_screenshot('tmp.png')
-    #     allure.attach.file('tmp.png', attachment_type=allure.attachment_type.PNG,
-    #                        name=f'{filename}-{get_time()}')
-    #     os.remove('tmp.png')
-
-    def get_page_content(self):
-        page_source = self.d.page_source
-        logger.info(f"获取页面内容: \n{page_source}")
-        return page_source
-
-    def max_window(self):
-        logger.info("窗口设置全屏")
-        self.d.maximize_window()
-
-    def set_window_size(self, width, height):
-        logger.info("设置窗口长宽")
-        self.d.set_window_size(width, height)
-
     def get_windows(self):
         logger.info(f"获取当前打开的窗口列表")
         return self.d.window_handles
@@ -229,11 +199,6 @@ class H5Driver(object):
         ][0]
         self.d.switch_to.window(newest_window)
 
-    def window_scroll(self, width, height):
-        logger.info(f"设置scroll bar的宽高")
-        js = "window.scrollTo({w},{h});".format(w=str(width), h=str(height))
-        self.d.execute_script(js)
-
     def switch_to_frame(self, frame_id):
         logger.info(f"切换到frame {frame_id}")
         self.d.switch_to.frame(frame_id)
@@ -246,64 +211,10 @@ class H5Driver(object):
         logger.info(f"执行js脚本: \n{script}")
         self.d.execute_script(script, *args)
 
-    def click(self, element):
+    def click_elem(self, element):
         logger.info(f"点击元素: {element}")
         self.d.execute_script("arguments[0].click();", element)
 
-    def quit(self):
-        logger.info("退出浏览器")
-        self.d.quit()
-
-    def close(self):
-        logger.info("关闭当前页签")
-        self.d.close()
-
-    def add_cookies(self, cookies: list):
-        for cookie in cookies:
-            self.d.add_cookie(cookie)
-
-    def get_cookies(self):
-        logger.info("获取cookies")
-        cookies = self.d.get_cookies()
-        logger.info(cookies)
-        return cookies
-
-    def get_cookie(self, name):
-        logger.info(f"获取cookie: {name}")
-        cookie = self.d.get_cookie(name)
-        logger.info(cookie)
-        return cookie
-
-    def delete_all_cookies(self):
-        logger.info("删除所有cookie")
-        self.d.delete_all_cookies()
-
-    def delete_cookie(self, name):
-        logger.info(f"删除cookie: {name}")
-        self.d.delete_cookie(name)
-
-    def refresh(self):
-        logger.info(f"刷新当前页")
-        self.d.refresh()
-
-    def get_title(self):
-        logger.info("获取页面标题")
-        title = self.d.title
-        logger.info(title)
-        return title
-
-    def get_url(self):
-        logger.info("获取页面url")
-        url = self.d.current_url
-        logger.info(url)
-        return url
-
-    def get_alert_text(self):
-        logger.info("获取alert的文本")
-        alert_text = self.d.switch_to.alert.text
-        logger.info(alert_text)
-        return alert_text
-
     def accept_alert(self):
         logger.info("同意确认框")
         self.d.switch_to.alert.accept()
