@@ -1,10 +1,7 @@
 import inspect
 import time
 
-from qrunner.core.image.element import ImageElem
-from qrunner.core.ocr.element import OCRElem
-from qrunner.utils.exceptions import ElementNameEmptyException, NoSuchElementException, DriverNotFound, \
-    LocMethodEmptyException
+from qrunner.utils.exceptions import ElementNameEmptyException, NoSuchElementException, DriverNotFound
 from qrunner.utils.log import logger
 from qrunner.core.ios.driver import IosDriver
 
@@ -156,15 +153,10 @@ class IosElem(object):
         @return:
         """
         logger.info(f"判断元素是否存在:")
-        if self._image is not None:
-            return self.image_exists(timeout=timeout)
-        elif self._ocr is not None:
-            return self.ocr_exists(timeout=timeout)
-        else:
-            element = self._find_element(retry=0, timeout=timeout)
-            if element is None:
-                return False
-            return True
+        element = self._find_element(retry=0, timeout=timeout)
+        if element is None:
+            return False
+        return True
 
     def click(self, retry=3, timeout=3):
         """
@@ -173,12 +165,7 @@ class IosElem(object):
         @param: timeout，每次重试超时时间
         """
         logger.info(f"点击元素")
-        if self._image is not None:
-            self.image_click(retry=retry, timeout=timeout)
-        elif self._ocr is not None:
-            self.ocr_click(retry=retry, timeout=timeout)
-        else:
-            self.get_element(retry=retry, timeout=timeout).click()
+        self.get_element(retry=retry, timeout=timeout).click()
 
     def click_exists(self, timeout=3):
         """元素存在时点击"""
@@ -223,26 +210,6 @@ class IosElem(object):
         """往下滑动"""
         self.get_element().swipe("down")
 
-    def image_click(self, retry=3, timeout=3):
-        """图像识别点击"""
-        _element = ImageElem(self._driver, image=self._image, desc=self._desc)
-        _element.click(retry=retry, timeout=timeout)
-
-    def image_exists(self, retry=3, timeout=3):
-        """图像是否存在"""
-        _element = ImageElem(self._driver, image=self._image, desc=self._desc)
-        return _element.exists(retry=retry, timeout=timeout)
-
-    def ocr_click(self, retry=3, timeout=1):
-        """ocr识别点击"""
-        _element = OCRElem(self._driver, text=self._ocr, desc=self._desc)
-        _element.click(retry=retry, timeout=timeout)
-
-    def ocr_exists(self, retry=3, timeout=1):
-        """文本是否在图像中存在"""
-        _element = OCRElem(self._driver, text=self._ocr, desc=self._desc)
-        return _element.exists(retry=retry, timeout=timeout)
-
 
 if __name__ == '__main__':
     driver = IosDriver()
